@@ -262,7 +262,7 @@ def build_doc ():
 
   with sys.stdout as out:
     out.write ("## Table of Content\n\n")
-    sorted_apis = sorted (apis.items (), key = lambda x: x [0])
+    sorted_apis = sorted (apis.items (), key = lambda x: sorted (list (x [1].endpoints))[0])
     for idx, (resource_id, api) in enumerate (sorted_apis):
       end_points = " | ".join (list (api.endpoints)).replace ("<", "&lt;").replace (">", "&gt;")
       out.write ("1. [{}](#{})".format (end_points, resource_id.replace (".", "").lower ()))
