@@ -1,8 +1,9 @@
-import fcntl, socket, struct
+import socket, struct
 import subprocess
 import os
 
 def get_mac (iname):
+    import fcntl
     s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
     info = fcntl.ioctl(s.fileno(), 0x8927,  struct.pack('256s', iname [:15].encode ("utf8")))
     return ':'.join(['%02x' % hex for hex in info[18:24]])
@@ -19,9 +20,8 @@ def get_ip ():
     return IP
 
 def get_hwid():
-    if 'nt' in os.name:
-        return subprocess.Popen('dmidecode.exe -s system-uuid'.split())
+    if os.name == 'nt':
+        return subprocess.check_output('wmic csproduct get uuid'.split()).decode ().split ()[-1]
     else:
-        return subprocess.Popen('hal-get-property --udi /org/freedesktop/Hal/devices/computer --key system.hardware.uuid'.split())
-        
-        
\ No newline at end of file
+        return subprocess.check_output('cat /sys/class/dmi/id/product_uuid'.split()).decode ().strip ()
+    
\ No newline at end of file
